@@ -7,10 +7,10 @@ use warnings;
 
 package POSIX::1003::Module;
 use vars '$VERSION';
-$VERSION = '0.93';
+$VERSION = '0.94_1';
 
 
-our $VERSION = '0.93';
+our $VERSION = '0.94_1';
 use Carp 'croak';
 
 { use XSLoader;
@@ -22,6 +22,8 @@ use Carp 'croak';
 my $in_constant_table;
 BEGIN { $in_constant_table = qr/
    ^_CS_    # confstr
+ | ^E(?!CHONL|XIT_) # errno   ECHONL in Termios, EXIT_ in Proc
+ | ^WSAE    # errno (windows sockets)
  | ^GET_    # rlimit
  | ^O_      # fdio
  | ^_PC_    # pathconf
@@ -108,12 +110,12 @@ sub import(@)
         elsif($f =~ s/^%//)
         {   $export = \%{"${class}::$f"};
         }
-        elsif($in_core && grep {$f eq $_} @$in_core)
+        elsif($in_core && grep $f eq $_, @$in_core)
         {   # function is in core, simply ignore the export
             next;
         }
         else
-        {   croak "unable to load $f";
+        {   croak "unable to load $f from $class";
         }
 
         no warnings 'once';
@@ -137,7 +139,7 @@ sub exampleValue($)
 
 package POSIX::1003::ReadOnlyTable;
 use vars '$VERSION';
-$VERSION = '0.93';
+$VERSION = '0.94_1';
 
 sub TIEHASH($) { bless $_[1], $_[0] }
 sub FETCH($)   { $_[0]->{$_[1]} }
